<?php
/**
 * Sample implementation of the Custom Header feature
 *
 * You can add an optional custom header image to header.php like so ...
 *
	<?php the_header_image_tag(); ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package redio writers
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses redio_writers_header_style()
 */
function redio_writers_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'redio_writers_custom_header_args', array(
		'default-text-color'     => 'ffffff',
		'flex-height'            => true,
		'wp-head-callback'       => 'redio_writers_header_style',
		'flex-width'			=> true,
		'flex-height'			=> true,
	) ) );
	register_default_headers( array( 
		'header-bg-two' => array(
			'url'           => get_theme_file_uri( '/images/header-default.png' ),
			'thumbnail_url' => get_theme_file_uri( '/images/header-default.png' ),
			'description'   => _x( 'Default', 'Default header image', 'redio-writers' )
		),	
	) );
}
add_action( 'after_setup_theme', 'redio_writers_custom_header_setup' );

if ( ! function_exists( 'redio_writers_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see redio_writers_custom_header_setup().
	 */
	function redio_writers_header_style() {
		$header_text_color = get_header_textcolor();
		$header_image = get_header_image();

		/*
		 * If no custom options for text are set, let's bail.
		 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
		 */
		if ( empty( $header_image ) && $header_text_color == get_theme_support( 'custom-header', 'default-text-color' ) ){
			return;
		}

	// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">



			<?php
			if(get_header_image()){ ?>

				.sheader {
				background-image: url(<?php header_image(); ?>);
			}
		<?php } ?>


		.site-title a,
		.site-description,
		.logofont {
		color: #<?php echo esc_attr( $header_text_color ); ?>;
	}

	<?php if ( ! display_header_text() ) : ?>
		a.logofont {
		position: absolute;
		clip: rect(1px, 1px, 1px, 1px);
		display:none;
	}
<?php endif; ?>

<?php header_image(); ?>"
<?php
if ( ! display_header_text() ) :
	?>
	a.logofont{
	position: absolute;
	clip: rect(1px, 1px, 1px, 1px);
	display:none;
}
<?php
else :
	?>
	.site-title a,
	.site-description {
	color: #<?php echo esc_attr( $header_text_color ); ?>;
}
<?php endif; ?>
</style>
<?php
}
endif;
